from django.apps import AppConfig


class Config(AppConfig):
    name = "unicef_security"
    verbose_name = "UNICEF Security"
